@@ -125,6 +125,15 @@ class BuildCommand(Command):
                         'project config'
                     )
 
+                for config in self.config.lib_configs:
+                    if lib == config.name:
+                        if config.restrict_arch and config.restrict_arch != config.arch:
+                            raise ClickableException(
+                                f'Cannot build library {config.name} for architecture '
+                                f'"{config.arch}" as it is restricted '
+                                f'to "{config.restrict_arch}" in the project config.'
+                            )
+
     def run(self):
         if self.libs is not None:
             self.build_libs()
@@ -200,7 +209,7 @@ class BuildCommand(Command):
         container.setup()
 
         if config.prebuild:
-            self.run_custom_commands(config.prebuild)
+            run_custom_commands(config.prebuild, config, container)
 
         run_builder(config, container, self.debug_build)
 
@@ -208,7 +217,7 @@ class BuildCommand(Command):
             self.install_additional_files()
 
         if config.postbuild:
-            self.run_custom_commands(config.postbuild)
+            run_custom_commands(config.postbuild, config, container)
 
     def install_files(self, pattern, dest_dir):
         if not is_sub_dir(dest_dir, self.config.install_dir):
@@ -325,10 +334,11 @@ class BuildCommand(Command):
 
         logger.debug('Click outputted to %s', self.click_path)
 
-    def run_custom_commands(self, commands):
-        if commands:
-            for cmd in commands:
-                self.container.run_command(cmd, cwd=self.config.cwd)
+
+def run_custom_commands(commands, config, container):
+    if commands:
+        for cmd in commands:
+            container.run_command(cmd, cwd=config.cwd)
 
 
 def run_builder(config, container, debug_build):
