@@ -1,9 +1,10 @@
-from clickable import ProjectConfig
+from clickable.config.project import ProjectConfig
 from clickable.commands.docker.docker_config import DockerConfig
 from .docker_support import DockerSupport
 import os
 import getpass
 
+
 class MultimediaSupport(DockerSupport):
     config = None
 
@@ -13,13 +14,12 @@ class MultimediaSupport(DockerSupport):
     def update(self, docker_config: DockerConfig):
         uid = os.getuid()
         user = getpass.getuser()
-        
+
         docker_config.volumes.update({
             '/dev/shm': '/dev/shm',
             '/etc/machine-id': '/etc/machine-id',
-            '/run/{}/pulse'.format(uid): '/run/user/1000/pulse',
+            '/run/user/{}/pulse'.format(uid): '/run/user/1000/pulse',
             '/var/lib/dbus': '/var/lib/dbus',
             '/home/{}/.pulse'.format(user): '/home/phablet/.pulse',
             '/dev/snd': '/dev/snd',
         })
-
