@@ -114,6 +114,7 @@ class ProjectConfig():
     lib_configs = []
     global_config = None
     skip_image_setup = False
+    arch_inferred = False
 
     def __init__(self, args=None, cwd=None, commands=None, always_clean=False):
         if not commands:
@@ -214,13 +215,6 @@ class ProjectConfig():
         if not self.commands:
             self.commands = self.config['default']
 
-        if (
-            self.config['always_clean']
-            and self.is_app_build_cmd()
-            and self.commands[0] != 'clean'
-        ):
-            self.commands = ['clean'] + self.commands
-
     def load_global_config(self, path):
         self.global_config = GlobalConfig(path)
 
@@ -244,6 +238,8 @@ class ProjectConfig():
             self.is_custom_docker_image = False
 
         if not self.config["arch"]:
+            self.arch_inferred = True
+
             if self.is_arch_agnostic():
                 self.config["arch"] = "all"
                 logger.debug(
@@ -285,6 +281,9 @@ class ProjectConfig():
             self.config['app_bin_dir'] = '${INSTALL_DIR}'
             self.config['app_qml_dir'] = '${INSTALL_DIR}/qml'
 
+        if self.config["arch"] == "host":
+            self.config["arch"] = Constants.host_arch
+
         if self.config['arch'] not in Constants.arch_triplet_mapping:
             raise ClickableException(
                 f'There is currently no support for architecture  "{self.config["arch"]}"'
@@ -319,6 +318,8 @@ class ProjectConfig():
                     self.config['kill'] = desktop['Exec'] \
                         .replace('%u', '').replace('%U', '').strip()
 
+        self.config['make_args'] = flexible_string_to_list(self.config['make_args'], split=True)
+
         make_jobs_args = get_make_jobs_from_args(self.config['make_args'])
         if make_jobs_args:
             if self.config['make_jobs']:
@@ -357,26 +358,26 @@ class ProjectConfig():
         if self.needs_clickable_image():
             self.check_nvidia_mode()
 
-            if self.use_nvidia and not self.build_arch.endswith('-nvidia'):
-                if self.is_ide_command():
-                    self.build_arch = f"{self.build_arch}-nvidia-ide"
-                else:
-                    self.build_arch = f"{self.build_arch}-nvidia"
+            container_spec = self.build_arch
 
-            if self.is_ide_command() and not self.use_nvidia:
-                self.build_arch = f"{self.build_arch}-ide"
+            if self.use_nvidia:
+                container_spec += "-nvidia"
+
+            if self.is_ide_command():
+                container_spec += "-ide"
 
             image_framework = Constants.framework_image_mapping.get(
                 self.config['framework'], Constants.framework_fallback)
 
             container_mapping_host = Constants.container_mapping[Constants.host_arch]
-            if (image_framework, self.build_arch) not in container_mapping_host:
+            container = container_mapping_host.get((image_framework, container_spec), None)
+
+            if not container:
                 raise ClickableException(
-                    f'There is currently no docker image for {image_framework}/{self.build_arch}'
+                    f'There is currently no docker image for {image_framework}/{container_spec}'
                 )
-            self.config['docker_image'] = container_mapping_host[
-                (image_framework, self.build_arch)
-            ]
+
+            self.config['docker_image'] = container
             self.container_list = list(container_mapping_host.values())
 
     def setup_helpers(self):
@@ -623,7 +624,7 @@ class ProjectConfig():
                 self.config[key] = make_absolute(self.config[key], change_keys=True)
 
     def set_build_arch(self):
-        if self.config['arch'] == 'all':
+        if self.config['arch'] in ['all', 'host']:
             self.build_arch = Constants.host_arch
         else:
             self.build_arch = self.config['arch']
@@ -653,6 +654,7 @@ class ProjectConfig():
             lib_init.name = name
             lib_init.config_dict = config
             lib_init.arch = self.config['arch']
+            lib_init.arch_inferred = self.arch_inferred
             lib_init.root_dir = self.config['root_dir']
             lib_init.qt_version = self.config['qt_version']
             lib_init.verbose = self.verbose
@@ -694,11 +696,8 @@ class ProjectConfig():
     def is_ide_command(self):
         return "ide" in self.commands
 
-    def is_app_build_cmd(self):
-        return self.is_desktop_mode() or 'build' in self.commands
-
     def is_build_cmd(self):
-        return self.is_app_build_cmd() or 'build-libs' in self.commands
+        return self.is_desktop_mode() or 'build' in self.commands
 
     def is_project_independent_cmd(self):
         return bool(set(['no_lock', 'writable_image', 'screenshots', 'create', 'setup'
@@ -728,15 +727,26 @@ class ProjectConfig():
         minimum_required = self.config['clickable_minimum_required']
 
         if self.config['clickable_minimum_required']:
-            # Check if specified version string is valid
-            if not re.fullmatch(r"\d+(\.\d+)*", self.config['clickable_minimum_required']):
-                raise ClickableException(
-                    f'"{minimum_required}" specified as "clickable_minimum_required" is not a '
-                    'valid version number'
-                )
+            clickable_required_numbers = []
+
+            if isinstance(self.config['clickable_minimum_required'], str):
+                # Check if specified version string is valid
+                if not re.fullmatch(r"\d+(\.\d+)*", self.config['clickable_minimum_required']):
+                    raise ClickableException(
+                        f'"{minimum_required}" specified as "clickable_minimum_required" is not a '
+                        'valid version number'
+                    )
+
+                clickable_required_numbers = split_version_numbers(
+                    minimum_required)
+            else:
+                value = self.config['clickable_minimum_required']
+                clickable_required_numbers.append(int(value))
+                fract = value % 1
+                if fract:
+                    # Get fract as integer without trailing zeros
+                    clickable_required_numbers.append(int(f'{fract:f}'[2:].strip("0")))
 
-            clickable_required_numbers = split_version_numbers(
-                minimum_required)
             if is_newer_than_running(clickable_required_numbers):
                 raise ClickableException(
                     f'This project requires Clickable version {minimum_required} '
@@ -747,7 +757,7 @@ class ProjectConfig():
                                'the "clickable_minimum_required" field. See %s for details about '
                                'migration to Clickable 7.', clickable_required_numbers[0],
                                migration_link)
-        else:
+        elif not self.is_project_independent_cmd():
             logger.warning('This project does not have a required Clickable version configured '
                            '("clickable_minimum_required"). See %s for details about migration to '
                            'Clickable 7 if you run into issues.', migration_link)
